.. meta::
   :description: Gaitalytics contribution.
   :keywords: gaitalytics, gait-analysis, mocap, c3d, gait-metrics, biomechanics, time-series, data-analysis, data, gait, contribution

.. include:: ../CONTRIBUTING.rst
